==> coil-1.1.1-javadoc.jar: coil-video/coil.request/video-frame-option.md <==
[coil-video](../index.md) / [coil.request](index.md) / [videoFrameOption](./video-frame-option.md)

# videoFrameOption

`fun `[`Builder`](https://coil-kt.github.io/coil/api/coil-base/coil.request/-image-request/-builder/index.html)`.videoFrameOption(option: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): `[`Builder`](https://coil-kt.github.io/coil/api/coil-base/coil.request/-image-request/-builder/index.html)

Set the option for how to decode the video frame.

Must be one of [OPTION_PREVIOUS_SYNC](https://developer.android.com/reference/android/media/MediaMetadataRetriever.html#OPTION_PREVIOUS_SYNC), [OPTION_NEXT_SYNC](https://developer.android.com/reference/android/media/MediaMetadataRetriever.html#OPTION_NEXT_SYNC), [OPTION_CLOSEST_SYNC](https://developer.android.com/reference/android/media/MediaMetadataRetriever.html#OPTION_CLOSEST_SYNC), [OPTION_CLOSEST](https://developer.android.com/reference/android/media/MediaMetadataRetriever.html#OPTION_CLOSEST).

Default: [OPTION_CLOSEST_SYNC](https://developer.android.com/reference/android/media/MediaMetadataRetriever.html#OPTION_CLOSEST_SYNC)

**See Also**

[MediaMetadataRetriever](https://developer.android.com/reference/android/media/MediaMetadataRetriever.html)

[VideoFrameFetcher](https://coil-kt.github.io/coil/api/coil-base/coil.fetch/-video-frame-fetcher/index.html)

`fun `[`Parameters`](https://coil-kt.github.io/coil/api/coil-base/coil.request/-parameters/index.html)`.videoFrameOption(): `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`?`

Get the option for how to decode the video frame.

**See Also**

[VideoFrameFetcher](https://coil-kt.github.io/coil/api/coil-base/coil.fetch/-video-frame-fetcher/index.html)

==> coil-1.2.0-javadoc.jar: coil-video/coil.request/video-frame-option.md <==
[coil-video](../index.md) / [coil.request](index.md) / [videoFrameOption](./video-frame-option.md)

# videoFrameOption

`fun `[`Builder`](https://coil-kt.github.io/coil/api/coil-base/coil.request/-image-request/-builder/index.html)`.videoFrameOption(option: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): `[`Builder`](https://coil-kt.github.io/coil/api/coil-base/coil.request/-image-request/-builder/index.html)

Set the option for how to decode the video frame.

Must be one of [OPTION_PREVIOUS_SYNC](https://developer.android.com/reference/android/media/MediaMetadataRetriever.html#OPTION_PREVIOUS_SYNC), [OPTION_NEXT_SYNC](https://developer.android.com/reference/android/media/MediaMetadataRetriever.html#OPTION_NEXT_SYNC), [OPTION_CLOSEST_SYNC](https://developer.android.com/reference/android/media/MediaMetadataRetriever.html#OPTION_CLOSEST_SYNC), [OPTION_CLOSEST](https://developer.android.com/reference/android/media/MediaMetadataRetriever.html#OPTION_CLOSEST).

Default: [OPTION_CLOSEST_SYNC](https://developer.android.com/reference/android/media/MediaMetadataRetriever.html#OPTION_CLOSEST_SYNC)

**See Also**

[MediaMetadataRetriever](https://developer.android.com/reference/android/media/MediaMetadataRetriever.html)

[VideoFrameDecoder](https://coil-kt.github.io/coil/api/coil-base/coil.decode/-video-frame-decoder/index.html)

[VideoFrameFetcher](https://coil-kt.github.io/coil/api/coil-base/coil.fetch/-video-frame-fetcher/index.html)

`fun `[`Parameters`](https://coil-kt.github.io/coil/api/coil-base/coil.request/-parameters/index.html)`.videoFrameOption(): `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`?`

Get the option for how to decode the video frame.

**See Also**

[VideoFrameFetcher](https://coil-kt.github.io/coil/api/coil-base/coil.fetch/-video-frame-fetcher/index.html)
